# motile: Multi-Object Tracking with Integer Linear Equations

[![License](https://img.shields.io/pypi/l/motile.svg)](https://github.com/funkelab/motile/raw/main/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/motile.svg)](https://pypi.org/project/motile)
[![CI](https://github.com/funkelab/motile/actions/workflows/ci.yaml/badge.svg)](https://github.com/funkelab/motile/actions/workflows/ci.yaml)
[![codecov](https://codecov.io/gh/funkelab/motile/branch/main/graph/badge.svg)](https://codecov.io/gh/funkelab/motile)

`motile` tracks multiple objects by solving a global optimization problem.

Read all about it in the [documentation](https://funkelab.github.io/motile/).

## Installation

```bash
pip install motile
```

## Development
Check out CONTRIBUTING.md for more information on contributing to `motile`.
